problem

package
v0.0.0-...-78d9c2c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 31, 2025 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

const MIMEProblemDetails = "application/problem+json"

Variables

This section is empty.

Functions

This section is empty.

Types

type Details

type Details struct {
	// A URI reference that identifies the problem type.
	// The specification encourages that, when dereferenced,
	// it provides human-readable documentation for the problem type.
	// When this member is not present, its value is assumed to be "about:blank".
	Type string `json:"type"`

	// A short, human-readable summary of the problem type.
	// It SHOULD NOT change from occurrence to occurrence of the problem,
	// except for purposes of localization.
	Title string `json:"title"`

	// The HTTP status code generated by the origin server for this occurrence of the problem.
	Status int `json:"status"`

	// A human-readable explanation specific to this occurrence of the problem.
	// The "detail" member, if present, ought to focus on helping the client correct the problem,
	// rather than giving debugging information.
	Detail string `json:"detail"`

	// A URI reference that identifies the specific occurrence of the problem.
	// It may or may not yield further information if dereferenced.
	Instance string `json:"instance"`
}

func (Details) MarshalEasyJSON

func (v Details) MarshalEasyJSON(w *jwriter.Writer)

MarshalEasyJSON supports easyjson.Marshaler interface

func (Details) MarshalJSON

func (v Details) MarshalJSON() ([]byte, error)

MarshalJSON supports json.Marshaler interface

func (*Details) UnmarshalEasyJSON

func (v *Details) UnmarshalEasyJSON(l *jlexer.Lexer)

UnmarshalEasyJSON supports easyjson.Unmarshaler interface

func (*Details) UnmarshalJSON

func (v *Details) UnmarshalJSON(data []byte) error

UnmarshalJSON supports json.Unmarshaler interface

Jump to